@@ -50,9 +50,9 @@ from airflow.providers.amazon.aws.sensors.eks import EksClusterStateSensor, EksN
 """
 
 with DAG(
-    dag_id='example_eks_templated',
+    dag_id="example_eks_templated",
     start_date=datetime(2021, 1, 1),
-    tags=['example', 'templated'],
+    tags=["example", "templated"],
     catchup=False,
     # render_template_as_native_obj=True is what converts the Jinja to Python objects, instead of a string.
     render_template_as_native_obj=True,
@@ -63,7 +63,7 @@ with DAG(
 
     # Create an Amazon EKS Cluster control plane without attaching a compute service.
     create_cluster = EksCreateClusterOperator(
-        task_id='create_eks_cluster',
+        task_id="create_eks_cluster",
         cluster_name=CLUSTER_NAME,
         compute=None,
         cluster_role_arn="{{ dag_run.conf['cluster_role_arn'] }}",
@@ -72,13 +72,13 @@ with DAG(
     )
 
     await_create_cluster = EksClusterStateSensor(
-        task_id='wait_for_create_cluster',
+        task_id="wait_for_create_cluster",
         cluster_name=CLUSTER_NAME,
         target_state=ClusterStates.ACTIVE,
     )
 
     create_nodegroup = EksCreateNodegroupOperator(
-        task_id='create_eks_nodegroup',
+        task_id="create_eks_nodegroup",
         cluster_name=CLUSTER_NAME,
         nodegroup_name=NODEGROUP_NAME,
         nodegroup_subnets="{{ dag_run.conf['nodegroup_subnets'] }}",
@@ -86,7 +86,7 @@ with DAG(
     )
 
     await_create_nodegroup = EksNodegroupStateSensor(
-        task_id='wait_for_create_nodegroup',
+        task_id="wait_for_create_nodegroup",
         cluster_name=CLUSTER_NAME,
         nodegroup_name=NODEGROUP_NAME,
         target_state=NodegroupStates.ACTIVE,
@@ -105,25 +105,25 @@ with DAG(
     )
 
     delete_nodegroup = EksDeleteNodegroupOperator(
-        task_id='delete_eks_nodegroup',
+        task_id="delete_eks_nodegroup",
         cluster_name=CLUSTER_NAME,
         nodegroup_name=NODEGROUP_NAME,
     )
 
     await_delete_nodegroup = EksNodegroupStateSensor(
-        task_id='wait_for_delete_nodegroup',
+        task_id="wait_for_delete_nodegroup",
         cluster_name=CLUSTER_NAME,
         nodegroup_name=NODEGROUP_NAME,
         target_state=NodegroupStates.NONEXISTENT,
     )
 
     delete_cluster = EksDeleteClusterOperator(
-        task_id='delete_eks_cluster',
+        task_id="delete_eks_cluster",
         cluster_name=CLUSTER_NAME,
     )
 
     await_delete_cluster = EksClusterStateSensor(
-        task_id='wait_for_delete_cluster',
+        task_id="wait_for_delete_cluster",
         cluster_name=CLUSTER_NAME,
         target_state=ClusterStates.NONEXISTENT,
     )
