@@ -38,8 +38,8 @@ def should_retry(exception: Exception):
     """Check if exception is related to ECS resource quota (CPU, MEM)."""
     if isinstance(exception, EcsOperatorError):
         return any(
-            quota_reason in failure['reason']
-            for quota_reason in ['RESOURCE:MEMORY', 'RESOURCE:CPU']
+            quota_reason in failure["reason"]
+            for quota_reason in ["RESOURCE:MEMORY", "RESOURCE:CPU"]
             for failure in exception.failures
         )
     return False
@@ -50,7 +50,7 @@ def should_retry_eni(exception: Exception):
     if isinstance(exception, EcsTaskFailToStart):
         return any(
             eni_reason in exception.message
-            for eni_reason in ['network interface provisioning', 'ResourceInitializationError']
+            for eni_reason in ["network interface provisioning", "ResourceInitializationError"]
         )
     return False
 
@@ -58,64 +58,88 @@ def should_retry_eni(exception: Exception):
 class EcsClusterStates(Enum):
     """Contains the possible State values of an ECS Cluster."""
 
-    ACTIVE = 'ACTIVE'
-    PROVISIONING = 'PROVISIONING'
-    DEPROVISIONING = 'DEPROVISIONING'
-    FAILED = 'FAILED'
-    INACTIVE = 'INACTIVE'
+    ACTIVE = "ACTIVE"
+    PROVISIONING = "PROVISIONING"
+    DEPROVISIONING = "DEPROVISIONING"
+    FAILED = "FAILED"
+    INACTIVE = "INACTIVE"
 
 
 class EcsTaskDefinitionStates(Enum):
     """Contains the possible State values of an ECS Task Definition."""
 
-    ACTIVE = 'ACTIVE'
-    INACTIVE = 'INACTIVE'
+    ACTIVE = "ACTIVE"
+    INACTIVE = "INACTIVE"
 
 
 class EcsTaskStates(Enum):
     """Contains the possible State values of an ECS Task."""
 
-    PROVISIONING = 'PROVISIONING'
-    PENDING = 'PENDING'
-    ACTIVATING = 'ACTIVATING'
-    RUNNING = 'RUNNING'
-    DEACTIVATING = 'DEACTIVATING'
-    STOPPING = 'STOPPING'
-    DEPROVISIONING = 'DEPROVISIONING'
-    STOPPED = 'STOPPED'
-    NONE = 'NONE'
+    PROVISIONING = "PROVISIONING"
+    PENDING = "PENDING"
+    ACTIVATING = "ACTIVATING"
+    RUNNING = "RUNNING"
+    DEACTIVATING = "DEACTIVATING"
+    STOPPING = "STOPPING"
+    DEPROVISIONING = "DEPROVISIONING"
+    STOPPED = "STOPPED"
+    NONE = "NONE"
 
 
 class EcsHook(AwsGenericHook):
     """
-    Interact with AWS Elastic Container Service, using the boto3 library
-    Hook attribute `conn` has all methods that listed in documentation
+    Interact with Amazon Elastic Container Service (ECS).
+    Provide thin wrapper around :external+boto3:py:class:`boto3.client("ecs") <ECS.Client>`.
+
+    Additional arguments (such as ``aws_conn_id``) may be specified and
+    are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html
-        - https://docs.aws.amazon.com/AmazonECS/latest/APIReference/Welcome.html
-
-    Additional arguments (such as ``aws_conn_id`` or ``region_name``) may be specified and
-        are passed down to the underlying AwsBaseHook.
-
-    .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsGenericHook`
-
-    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
+        - `Amazon Elastic Container Service \
+        <https://docs.aws.amazon.com/AmazonECS/latest/APIReference/Welcome.html>`__
     """
 
     def __init__(self, *args, **kwargs) -> None:
-        kwargs['client_type'] = 'ecs'
+        kwargs["client_type"] = "ecs"
         super().__init__(*args, **kwargs)
 
     def get_cluster_state(self, cluster_name: str) -> str:
-        return self.conn.describe_clusters(clusters=[cluster_name])['clusters'][0]['status']
+        """
+        Get ECS Cluster state.
+
+        .. seealso::
+            - :external+boto3:py:meth:`ECS.Client.describe_clusters`
+
+        :param cluster_name: ECS Cluster name or full cluster Amazon Resource Name (ARN) entry.
+        """
+        return self.conn.describe_clusters(clusters=[cluster_name])["clusters"][0]["status"]
 
     def get_task_definition_state(self, task_definition: str) -> str:
-        return self.conn.describe_task_definition(taskDefinition=task_definition)['taskDefinition']['status']
+        """
+        Get ECS Task Definition state.
+
+        .. seealso::
+            - :external+boto3:py:meth:`ECS.Client.describe_task_definition`
+
+        :param task_definition: The family for the latest ACTIVE revision,
+            family and revision ( family:revision ) for a specific revision in the family,
+            or full Amazon Resource Name (ARN) of the task definition to describe.
+        """
+        return self.conn.describe_task_definition(taskDefinition=task_definition)["taskDefinition"]["status"]
 
     def get_task_state(self, cluster, task) -> str:
-        return self.conn.describe_tasks(cluster=cluster, tasks=[task])['tasks'][0]['lastStatus']
+        """
+        Get ECS Task state.
+
+        .. seealso::
+            - :external+boto3:py:meth:`ECS.Client.describe_tasks`
+
+        :param cluster: The short name or full Amazon Resource Name (ARN)
+            of the cluster that hosts the task or tasks to describe.
+        :param task: Task ID or full ARN entry.
+        """
+        return self.conn.describe_tasks(cluster=cluster, tasks=[task])["tasks"][0]["lastStatus"]
 
 
 class EcsTaskLogFetcher(Thread):
@@ -131,7 +155,7 @@ class EcsTaskLogFetcher(Thread):
         log_stream_name: str,
         fetch_interval: timedelta,
         logger: Logger,
-        aws_conn_id: str | None = 'aws_default',
+        aws_conn_id: str | None = "aws_default",
         region_name: str | None = None,
     ):
         super().__init__()
@@ -158,22 +182,22 @@ class EcsTaskLogFetcher(Thread):
         try:
             yield from self.hook.get_log_events(self.log_group, self.log_stream_name, skip=skip)
         except ClientError as error:
-            if error.response['Error']['Code'] != 'ResourceNotFoundException':
-                self.logger.warning('Error on retrieving Cloudwatch log events', error)
+            if error.response["Error"]["Code"] != "ResourceNotFoundException":
+                self.logger.warning("Error on retrieving Cloudwatch log events", error)
 
             yield from ()
         except ConnectionClosedError as error:
-            self.logger.warning('ConnectionClosedError on retrieving Cloudwatch log events', error)
+            self.logger.warning("ConnectionClosedError on retrieving Cloudwatch log events", error)
             yield from ()
 
     def _event_to_str(self, event: dict) -> str:
-        event_dt = datetime.utcfromtimestamp(event['timestamp'] / 1000.0)
-        formatted_event_dt = event_dt.strftime('%Y-%m-%d %H:%M:%S,%f')[:-3]
-        message = event['message']
-        return f'[{formatted_event_dt}] {message}'
+        event_dt = datetime.utcfromtimestamp(event["timestamp"] / 1000.0)
+        formatted_event_dt = event_dt.strftime("%Y-%m-%d %H:%M:%S,%f")[:-3]
+        message = event["message"]
+        return f"[{formatted_event_dt}] {message}"
 
     def get_last_log_messages(self, number_messages) -> list:
-        return [log['message'] for log in deque(self._get_log_events(), maxlen=number_messages)]
+        return [log["message"] for log in deque(self._get_log_events(), maxlen=number_messages)]
 
     def get_last_log_message(self) -> str | None:
         try:
