@@ -24,6 +24,7 @@ import io
 import logging
 import re
 import shutil
+import warnings
 from contextlib import suppress
 from copy import deepcopy
 from datetime import datetime
@@ -42,6 +43,7 @@ from botocore.exceptions import ClientError
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.exceptions import S3HookUriParseFailure
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
+from airflow.providers.amazon.aws.utils.tags import format_tags
 from airflow.utils.helpers import chunks
 
 T = TypeVar("T", bound=Callable)
@@ -64,7 +66,17 @@ def provide_bucket_name(func: T) -> T:
 
         if "bucket_name" not in bound_args.arguments:
             self = args[0]
-            if self.conn_config and self.conn_config.schema:
+
+            if "bucket_name" in self.service_config:
+                bound_args.arguments["bucket_name"] = self.service_config["bucket_name"]
+            elif self.conn_config and self.conn_config.schema:
+                warnings.warn(
+                    "s3 conn_type, and the associated schema field, is deprecated."
+                    " Please use aws conn_type instead, and specify `bucket_name`"
+                    " in `service_config.s3` within `extras`.",
+                    DeprecationWarning,
+                    stacklevel=2,
+                )
                 bound_args.arguments["bucket_name"] = self.conn_config.schema
 
         return func(*bound_args.args, **bound_args.kwargs)
@@ -108,7 +120,9 @@ def unify_bucket_name_and_key(func: T) -> T:
 
 class S3Hook(AwsBaseHook):
     """
-    Interact with AWS S3, using the boto3 library.
+    Interact with Amazon Simple Storage Service (S3).
+    Provide thick wrapper around :external+boto3:py:class:`boto3.client("s3") <S3.Client>`
+    and :external+boto3:py:class:`boto3.resource("s3") <S3.ServiceResource>`.
 
     :param transfer_config_args: Configuration object for managed S3 transfers.
     :param extra_args: Extra arguments that may be passed to the download/upload operations.
@@ -123,7 +137,7 @@ class S3Hook(AwsBaseHook):
     are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
     def __init__(
@@ -215,6 +229,9 @@ class S3Hook(AwsBaseHook):
         """
         Check if bucket_name exists.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.head_bucket`
+
         :param bucket_name: the name of the bucket
         :return: True if it exists and False if not.
         """
@@ -240,7 +257,10 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     def get_bucket(self, bucket_name: str | None = None) -> object:
         """
-        Returns a boto3.S3.Bucket object
+        Returns a :py:class:`S3.Bucket` object
+
+        .. seealso::
+            - :external+boto3:py:meth:`S3.ServiceResource.Bucket`
 
         :param bucket_name: the name of the bucket
         :return: the bucket object to the bucket name.
@@ -258,6 +278,9 @@ class S3Hook(AwsBaseHook):
         """
         Creates an Amazon S3 bucket.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.create_bucket`
+
         :param bucket_name: The name of the bucket
         :param region_name: The name of the aws region in which to create the bucket.
         """
@@ -304,6 +327,9 @@ class S3Hook(AwsBaseHook):
         """
         Lists prefixes in a bucket under prefix
 
+        .. seealso::
+            - :external+boto3:py:class:`S3.Paginator.ListObjectsV2`
+
         :param bucket_name: the name of the bucket
         :param prefix: a key prefix
         :param delimiter: the delimiter marks key hierarchy.
@@ -358,6 +384,9 @@ class S3Hook(AwsBaseHook):
         """
         Lists keys in a bucket under prefix and not containing delimiter
 
+        .. seealso::
+            - :external+boto3:py:class:`S3.Paginator.ListObjectsV2`
+
         :param bucket_name: the name of the bucket
         :param prefix: a key prefix
         :param delimiter: the delimiter marks key hierarchy.
@@ -430,6 +459,9 @@ class S3Hook(AwsBaseHook):
         """
         Lists metadata objects in a bucket under prefix
 
+        .. seealso::
+            - :external+boto3:py:class:`S3.Paginator.ListObjectsV2`
+
         :param prefix: a key prefix
         :param bucket_name: the name of the bucket
         :param page_size: pagination size
@@ -456,6 +488,9 @@ class S3Hook(AwsBaseHook):
         """
         Retrieves metadata of an object
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.head_object`
+
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which the file is stored
         :return: metadata of an object
@@ -474,6 +509,9 @@ class S3Hook(AwsBaseHook):
         """
         Checks if a key exists in a bucket
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.head_object`
+
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which the file is stored
         :return: True if the key exists and False if not.
@@ -485,7 +523,10 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     def get_key(self, key: str, bucket_name: str | None = None) -> S3Transfer:
         """
-        Returns a boto3.s3.Object
+        Returns a :py:class:`S3.Object`.
+
+        .. seealso::
+            - :external+boto3:py:meth:`S3.ServiceResource.Object`
 
         :param key: the path to the key
         :param bucket_name: the name of the bucket
@@ -507,6 +548,9 @@ class S3Hook(AwsBaseHook):
         """
         Reads a key from S3
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Object.get`
+
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which the file is stored
         :return: the content of the key
@@ -528,6 +572,9 @@ class S3Hook(AwsBaseHook):
         """
         Reads a key with S3 Select.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.select_object_content`
+
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which the file is stored
         :param expression: S3 Select expression
@@ -535,10 +582,6 @@ class S3Hook(AwsBaseHook):
         :param input_serialization: S3 Select input data serialization format
         :param output_serialization: S3 Select output data serialization format
         :return: retrieved subset of original data by S3 Select
-
-        .. seealso::
-            For more details about S3 Select parameters:
-            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.select_object_content
         """
         expression = expression or "SELECT * FROM S3Object"
         expression_type = expression_type or "SQL"
@@ -614,6 +657,9 @@ class S3Hook(AwsBaseHook):
         """
         Loads a local file to S3
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.upload_file`
+
         :param filename: path to the file to load.
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which to store the file
@@ -664,6 +710,9 @@ class S3Hook(AwsBaseHook):
         This is provided as a convenience to drop a string in S3. It uses the
         boto infrastructure to ship a file to s3.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.upload_fileobj`
+
         :param string_data: str to set as content for the key.
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which to store the file
@@ -712,6 +761,9 @@ class S3Hook(AwsBaseHook):
         This is provided as a convenience to drop bytes data into S3. It uses the
         boto infrastructure to ship a file to s3.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.upload_fileobj`
+
         :param bytes_data: bytes to set as content for the key.
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which to store the file
@@ -740,6 +792,9 @@ class S3Hook(AwsBaseHook):
         """
         Loads a file object to S3
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.upload_fileobj`
+
         :param file_obj: The file-like object to set as the content for the S3 key.
         :param key: S3 key that will point to the file
         :param bucket_name: Name of the bucket in which to store the file
@@ -791,6 +846,9 @@ class S3Hook(AwsBaseHook):
         """
         Creates a copy of an object that is already stored in S3.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.copy_object`
+
         Note: the S3 connection used here needs to have access to both
         source and destination bucket/key.
 
@@ -834,6 +892,9 @@ class S3Hook(AwsBaseHook):
         """
         To delete s3 bucket, delete all s3 bucket objects and then delete the bucket.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.delete_bucket`
+
         :param bucket_name: Bucket name
         :param force_delete: Enable this to delete bucket even if not empty
         :return: None
@@ -848,6 +909,9 @@ class S3Hook(AwsBaseHook):
         """
         Delete keys from the bucket.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.delete_objects`
+
         :param bucket: Name of the bucket in which you are going to delete object(s)
         :param keys: The key(s) to delete from S3 bucket.
 
@@ -886,6 +950,9 @@ class S3Hook(AwsBaseHook):
         """
         Downloads a file from the S3 location to the local file system.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Object.download_fileobj`
+
         :param key: The key path in S3.
         :param bucket_name: The specific bucket to use.
         :param local_path: The local path to the downloaded file. If no path is provided it will use the
@@ -953,6 +1020,9 @@ class S3Hook(AwsBaseHook):
         """
         Generate a presigned url given a client, its method, and arguments
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.generate_presigned_url`
+
         :param client_method: The client method to presign for.
         :param params: The parameters normally passed to ClientMethod.
         :param expires_in: The number of seconds the presigned url is valid for.
@@ -976,6 +1046,9 @@ class S3Hook(AwsBaseHook):
         """
         Gets a List of tags from a bucket.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.get_bucket_tagging`
+
         :param bucket_name: The name of the bucket.
         :return: A List containing the key/value pairs for the tags
         """
@@ -991,33 +1064,43 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     def put_bucket_tagging(
         self,
-        tag_set: list[dict[str, str]] | None = None,
+        tag_set: dict[str, str] | list[dict[str, str]] | None = None,
         key: str | None = None,
         value: str | None = None,
         bucket_name: str | None = None,
     ) -> None:
         """
-        Overwrites the existing TagSet with provided tags.  Must provide either a TagSet or a key/value pair.
+        Overwrites the existing TagSet with provided tags.
+        Must provide a TagSet, a key/value pair, or both.
 
-        :param tag_set: A List containing the key/value pairs for the tags.
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.put_bucket_tagging`
+
+        :param tag_set: A dictionary containing the key/value pairs for the tags,
+            or a list already formatted for the API
         :param key: The Key for the new TagSet entry.
         :param value: The Value for the new TagSet entry.
         :param bucket_name: The name of the bucket.
+
         :return: None
         """
-        self.log.info("S3 Bucket Tag Info:\tKey: %s\tValue: %s\tSet: %s", key, value, tag_set)
-        if not tag_set:
-            tag_set = []
+        formatted_tags = format_tags(tag_set)
+
         if key and value:
-            tag_set.append({"Key": key, "Value": value})
-        elif not tag_set or (key or value):
-            message = "put_bucket_tagging() requires either a predefined TagSet or a key/value pair."
+            formatted_tags.append({"Key": key, "Value": value})
+        elif key or value:
+            message = (
+                "Key and Value must be specified as a pair. "
+                f"Only one of the two had a value (key: '{key}', value: '{value}')"
+            )
             self.log.error(message)
             raise ValueError(message)
 
+        self.log.info("Tagging S3 Bucket %s with %s", bucket_name, formatted_tags)
+
         try:
             s3_client = self.get_conn()
-            s3_client.put_bucket_tagging(Bucket=bucket_name, Tagging={"TagSet": tag_set})
+            s3_client.put_bucket_tagging(Bucket=bucket_name, Tagging={"TagSet": formatted_tags})
         except ClientError as e:
             self.log.error(e)
             raise e
@@ -1027,6 +1110,9 @@ class S3Hook(AwsBaseHook):
         """
         Deletes all tags from a bucket.
 
+        .. seealso::
+            - :external+boto3:py:meth:`S3.Client.delete_bucket_tagging`
+
         :param bucket_name: The name of the bucket.
         :return: None
         """
