@@ -34,6 +34,8 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
     uploads to and reads from S3 remote storage.
     """
 
+    trigger_should_wrap = True
+
     def __init__(self, base_log_folder: str, s3_log_folder: str, filename_template: str | None = None):
         super().__init__(base_log_folder, filename_template)
         self.remote_base = s3_log_folder
@@ -53,9 +55,10 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
         super().set_context(ti)
         # Local location and remote location is needed to open and
         # upload local log file to S3 remote storage.
-        self.log_relative_path = self._render_filename(ti, ti.try_number)
-        self.upload_on_close = not ti.raw
-
+        full_path = self.handler.baseFilename
+        self.log_relative_path = pathlib.Path(full_path).relative_to(self.local_base).as_posix()
+        is_trigger_log_context = getattr(ti, "is_trigger_log_context", False)
+        self.upload_on_close = is_trigger_log_context or not ti.raw
         # Clear the file first so that duplicate data is not uploaded
         # when re-using the same path (e.g. with rescheduled sensors)
         if self.upload_on_close:
@@ -86,42 +89,47 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
         # Mark closed so we don't double write if close is called twice
         self.closed = True
 
+    def _read_remote_logs(self, ti, try_number, metadata=None):
+        # Explicitly getting log relative path is necessary as the given
+        # task instance might be different than task instance passed in
+        # in set_context method.
+        worker_log_rel_path = self._render_filename(ti, try_number)
+
+        logs = []
+        messages = []
+        bucket, prefix = self.hook.parse_s3_url(s3url=os.path.join(self.remote_base, worker_log_rel_path))
+        keys = self.hook.list_keys(bucket_name=bucket, prefix=prefix)
+        if keys:
+            keys = [f"s3://{bucket}/{key}" for key in keys]
+            messages.extend(["Found logs in s3:", *[f"  * {x}" for x in sorted(keys)]])
+            for key in sorted(keys):
+                logs.append(self.s3_read(key, return_error=True))
+        else:
+            messages.append(f"No logs found on s3 for ti={ti}")
+        return messages, logs
+
     def _read(self, ti, try_number, metadata=None):
         """
         Read logs of given task instance and try_number from S3 remote storage.
         If failed, read the log from task instance host machine.
 
+        todo: when min airflow version >= 2.6 then remove this method (``_read``)
+
         :param ti: task instance object
         :param try_number: task instance try_number to read logs from
         :param metadata: log metadata,
                          can be used for steaming log reading and auto-tailing.
         """
-        # Explicitly getting log relative path is necessary as the given
-        # task instance might be different than task instance passed in
-        # in set_context method.
-        log_relative_path = self._render_filename(ti, try_number)
-        remote_loc = os.path.join(self.remote_base, log_relative_path)
-
-        log_exists = False
-        log = ""
-
-        try:
-            log_exists = self.s3_log_exists(remote_loc)
-        except Exception as error:
-            self.log.exception("Failed to verify remote log exists %s.", remote_loc)
-            log = f"*** Failed to verify remote log exists {remote_loc}.\n{error}\n"
-
-        if log_exists:
-            # If S3 remote file exists, we do not fetch logs from task instance
-            # local machine even if there are errors reading remote logs, as
-            # returned remote_log will contain error messages.
-            remote_log = self.s3_read(remote_loc, return_error=True)
-            log = f"*** Reading remote log from {remote_loc}.\n{remote_log}\n"
-            return log, {"end_of_log": True}
+        # from airflow 2.6 we no longer implement the _read method
+        if hasattr(super(), "_read_remote_logs"):
+            return super()._read(ti, try_number, metadata)
+        # if we get here, we're on airflow < 2.6 and we use this backcompat logic
+        messages, logs = self._read_remote_logs(ti, try_number, metadata)
+        if logs:
+            return "".join(f"*** {x}\n" for x in messages) + "\n".join(logs), {"end_of_log": True}
         else:
-            log += "*** Falling back to local log\n"
             local_log, metadata = super()._read(ti, try_number, metadata)
-            return log + local_log, metadata
+            return "*** Falling back to local log\n" + local_log, metadata
 
     def s3_log_exists(self, remote_log_location: str) -> bool:
         """
@@ -172,7 +180,7 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
 
         # Default to a single retry attempt because s3 upload failures are
         # rare but occasionally occur.  Multiple retry attempts are unlikely
-        # to help as they usually indicate non-empheral errors.
+        # to help as they usually indicate non-ephemeral errors.
         for try_num in range(1 + max_retry):
             try:
                 self.hook.load_string(
