@@ -21,7 +21,7 @@ from __future__ import annotations
 import warnings
 
 from airflow.compat.functools import cached_property
-from airflow.providers.amazon.aws.utils import get_airflow_version, trim_none_values
+from airflow.providers.amazon.aws.utils import trim_none_values
 from airflow.secrets import BaseSecretsBackend
 from airflow.utils.log.logging_mixin import LoggingMixin
 
@@ -66,9 +66,9 @@ class SystemsManagerParameterStoreBackend(BaseSecretsBackend, LoggingMixin):
 
     def __init__(
         self,
-        connections_prefix: str = '/airflow/connections',
-        variables_prefix: str = '/airflow/variables',
-        config_prefix: str = '/airflow/config',
+        connections_prefix: str = "/airflow/connections",
+        variables_prefix: str = "/airflow/variables",
+        config_prefix: str = "/airflow/config",
         **kwargs,
     ):
         super().__init__()
@@ -77,11 +77,11 @@ class SystemsManagerParameterStoreBackend(BaseSecretsBackend, LoggingMixin):
         else:
             self.connections_prefix = connections_prefix
         if variables_prefix is not None:
-            self.variables_prefix = variables_prefix.rstrip('/')
+            self.variables_prefix = variables_prefix.rstrip("/")
         else:
             self.variables_prefix = variables_prefix
         if config_prefix is not None:
-            self.config_prefix = config_prefix.rstrip('/')
+            self.config_prefix = config_prefix.rstrip("/")
         else:
             self.config_prefix = config_prefix
 
@@ -131,16 +131,18 @@ class SystemsManagerParameterStoreBackend(BaseSecretsBackend, LoggingMixin):
         As of Airflow version 2.3.0 this method is deprecated.
 
         :param conn_id: the connection id
-        :return: deserialized Connection
         """
-        if get_airflow_version() >= (2, 3):
-            warnings.warn(
-                f"Method `{self.__class__.__name__}.get_conn_uri` is deprecated and will be removed "
-                "in a future release.  Please use method `get_conn_value` instead.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        return self.get_conn_value(conn_id)
+        warnings.warn(
+            f"Method `{self.__class__.__name__}.get_conn_uri` is deprecated and will be removed "
+            "in a future release. Please use method `get_conn_value` instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        value = self.get_conn_value(conn_id)
+        if value is None:
+            return None
+
+        return self.deserialize_connection(conn_id, value).get_uri()
 
     def get_variable(self, key: str) -> str | None:
         """
